Skip to contents

This function checks that the column names of a data frame (or multiple data frames) are part of a set of standard terms from the Darwin Core. It will output the columns that do not follow the standard names and can merge data frames if specified.

Usage

check_column_names(
  df_input,
  standard_terms = dwc_names,
  verbose = TRUE,
  merge = FALSE
)

Arguments

df_input

A data frame or a list of data frames to check.

standard_terms

A character vector containing the standard column names (default is dwc_names).

verbose

A logical value indicating whether to output the columns that do not match the standard terms (default is TRUE).

merge

A logical value indicating whether to merge data frames if all have the same names (default is FALSE).

Value

If merging is enabled and all data frames have the same column names, it returns a merged data frame. If verbosity is enabled, it prints out any columns that do not match the standard terms.

Examples