Skip to contents

This function launches a miniUI Shiny app that allows the user to fill in metadata according to Dublin Core standards and download an XML file.

Usage

run_metadata_app()

Value

Launches a miniUI Shiny app.