Check Data Frame Column Names Against Darwin Core Standard Terms
check_column_names.RdThis function checks that the column names of a data frame (or multiple data frames) are part of a set of standard terms from the Darwin Core. It will output the columns that do not follow the standard names and can merge data frames if specified.
Arguments
- df_input
A data frame or a list of data frames to check.
- standard_terms
A character vector containing the standard column names (default is
dwc_names).- verbose
A logical value indicating whether to output the columns that do not match the standard terms (default is TRUE).
- merge
A logical value indicating whether to merge data frames if all have the same names (default is FALSE).