run_metadata_app.Rd
This function launches a miniUI Shiny app that allows the user to fill in metadata according to Dublin Core standards and download an XML file.
run_metadata_app()
Launches a miniUI Shiny app.